/*************************************************************************************************

The Common Components method makes site-specific metadata (e.g., data table names, 
folder locations, ETL facts) available to programs distributed to the 
Mini-Sentinel Distributed Network .  Each Mini-Sentinel data partner has a SAS file called 
ms_common_components.sas that assigns site-specific values to standard macro variables.  

The common components file contains macro variables that define attributes such as: 
* Data partner description variables
* Most recent approved ETL version number
* Min and Max dates corresponding to the time window with complete data for most recent ETL
* Key Mini-Sentinel directory paths
* MSCDM table names
* SAS Module Yes/No Flags

Some ETL related metadata (e.g. ETL version and Min/Max dates) are automatically derived from
the ETL metadata produced from the QA package, while other ETL related metadata (e.g. directory
paths) need to be defined explicitly by the data partner

Please consult as needed with your local contacts for MSCDM maintenance/QA review for assistance with 
obtaining the directory paths needed for the macro variables _mscdm, _qaresults, and _staging

The common components file itself "includes" a macro package -- ms_setup_macros.sas -- to assist
with cleaning and validating path assignments and libname assignments

--------------------------------------------------------------------------------------------------
Date (mm/dd/yy):  01/07/15
Version: v1.2
**************************************************************************************************
Data Partner Description Macro Variables
**************************************************************************************************
DATA PARTNER NAME                         DPID      SITEID 

Data partners with one site (SITEID=OS)
Healthcore 					                       HC         OS     
Humana                                     HU         OS    
Aetna                                      AE         OS 
Optum                                      OP         OS
Vanderbilt University                      VB         OS

HMORN (7 sites)                                             
Group Health Cooperative                   HM         GHC    
Fallon Community Health Plan               HM         MPCI     
Henry Ford Health System                   HM         HFHS   
Lovelace Health System                     HM         LCF     
Marshfield Clinic                          HM         MCRF   
HealthPartners                             HM         HPRF   
Harvard Pilgrim Health Care                HM         HPHC   

Kaiser Permanente (6 sites + 1 data coordinating center)                                     
Kaiser Permanente Colorado                 KP         CO     
Kaiser Permanente Georgia                  KP         GA      
Kaiser Permanente Hawaii                   KP         HI      
Kaiser Permanente Northern California      KP         NC     
Kaiser Permanente Northwest                KP         NW     
Kaiser Permanente Mid Atlantic             KP         MA     
Kaiser Permanente Data Coordinating Center KP         DCC

Blue Cross Blue Shield Association
Blue Cross Blue Shield of Massachusetts    BC         BSMA

Hospital Corporation of America            HC         A

Mini-Sentinel Operations Center            MS         OC
**************************************************************************************************/
*Full name of the data partner (like above);
%LET DPName= edit-DP-Name ;

*Data Partner ID (like above);
%LET DPID= edit-DP-ID;   

*Data Partner Site ID (like above);                      
%LET SITEID= edit-Site-ID;                       

/***********************************************************************************
Data Partner Directory Macro Variables

IMPORTANT NOTES: 
  1- DO use forward slashes (e.g. /) which are always compatible on both UNIX and WINDOWS 
  2- DO use end of path separators (e.g. /xyz/ and not /xyz) which are assumed by many programs
  3- Do NOT surround directory paths with quotes (e.g. /xyz/ not "/xyz/") which the break the code
  4- DO consult the DP MSCDM/QA contacts list to help verify that the correct 
***********************************************************************************/

*Directory containing the Mini-Sentinel Common Data Model for most recent production ETL*;
%let _mscdm= edit-path ;

*Directory containing the ETL (MSCDM) in process used by the MSOC QA programs *;
*(can be blank, do NOT comment out) *;
%let _staging=;  

*Directory/folder containing the QA result datasets specific to the most recent production ETL;
%let _qaresults= edit-path ;

/*----------------------------------------------------------------------------------------------*/
/* >> The Linkage between Common Components Root-Path parms and Request Subdirectory parms <<   */
/*----------------------------------------------------------------------------------------------*/
/* For each standard workplan subdirectory, a root-path is defined in the common components.    */
/* The common component root-path parameters are NOT request specific as this would defeat the  */
/* purpose of common components.  But when combined with parameters from the program header for */
/* a specific request, the full paths specific to that request are dynamically generated.       */
/*                                                                                              */
/* It helps to see how the root-path parameters will be used by the program header [note that   */ 
/* for that for most data partners, all root-path parameters will point to the same directory]. */
/*                                                                                              */
/* Request Subdirectory parms copied from the example program header [ms_program_header.sas]    */              
/*   %let DPLOCAL = &_root_dplocal.&MSReqID./dplocal/ ;                                         */
/*   %let MSOC = &_root_msoc.&MSeqQID./msoc/ ;                                                  */
/*   %let INFOLDER = &_root_inputfiles.&MSReqID./inputfiles/ ;                                  */
/*   %let SASPROGRAMS = &_root_sasprograms.&MSReqID./sasprograms/ ;                             */
/*                                                                                              */
/* Taking DPLOCAL as an example, let us illustrate how parameters are resolved to dynamically    */
/* build the full path to dplocal subdirectory for request to07_nme_dabi_wgr_wp005_b03          */
/*                                                                                              */
/*   &_root_dplocal    -->    //sentinel/requests/                                              */
/*   &MSReqID:         -->    to07_nme_dabi_ahr_wp005_b03                                       */
/*   &DPLOCAL:         -->    //sentinel/requests/to07_nme_dabi_ahr_wp005_b03/dplocal/          */
/*----------------------------------------------------------------------------------------------*/  

*Read instructions above in lines 76-82 and lines 96-117 carefully before proceeding *;
*Root directories to subdirectories for Mini-Sentinel project workplans (excluding request-ID) *;
%let _root_dplocal = edit-path ;  
%let _root_msoc = edit-path ;   
%let _root_inputfiles = edit-path ;    
%let _root_sasprograms = edit-path ;  

***********************************************************************************
Data Partner MSCDM SAS Dataset/View Names

Specify the table names.

For example,  
%let ENRTABLE=enrollment
***********************************************************************************;
%let ENRTABLE=enrollment;    *specify the  enrollment table name    *;        
%let DEMTABLE=demographic;   *specify the  demographic table name   *;        
%let DISTABLE=dispensing;    *specify the  rx dispensing table name *;        
%let DIATABLE=diagnosis;     *specify the  diagnosis table name     *;        
%let PROCTABLE=procedure;    *specify the  procedure table name     *;        
%let ENCTABLE=encounter;     *specify the  encounter table name     *;  

***********************************************************************************
The following tables may not be available at all Data Partners.  Leave blank if they
are not available at your site.  Ensure the macro variables below are not commented
out (even if the table does NOT exist at your site).
***********************************************************************************;

%let DEATHTABLE= ;        *specify the death table name          *;        
%let CODTABLE= ;          *specify the cause_of_death table name *;              
%let LABTABLE= ;          *specify the lab_result table name     *;        
%let VITTABLE= ;          *specify the vital_sign table name     *;        

%let STATVACCTABLE = ;    *specify the State Vaccine table name*;

%let IPHARMTABLE  = ;     * specify an inpatient pharmacy table name *;
%let ITRANSTABLE = ;      * specify an inpatient transfusion table name *;

***********************************************************************************
Data Partner SAS options
***********************************************************************************;

****************************************
SAS/Graph Available  
Y=Yes, N=No
****************************************;
%let _sas_graph=Y;   * Y=Yes, N=No;

****************************************
SAS/Stat Available
Y=Yes, N=No
****************************************;
%let _sas_stat =Y;   * Y=Yes, N=No;

****************************************
SAS/Aces Interface to PC files Available
Y=Yes, N=No
****************************************;
%let _sas_access =Y;  * Y=Yes, N=No;


****************************************
Define path to MS Setup Macro Package
****************************************;
%let MS_SETUP_MACROS = edit-path ;


***********************************************************************************
*********                                                                 *********
*********                    DO NOT EDIT BELOW THIS LINE                  *********
*********               (Consult with MSOC if edits required)             *********
*********                                                                 *********
***********************************************************************************;

****************************************
Include the MS Setup Macro Package
****************************************;
%inc "&MS_SETUP_MACROS./ms_setup_macros.sas" /nosource;

***********************************************************************************
Key Libname Assignments.
***********************************************************************************;

/* Clean up paths (e.g. convert slashes and add slashes when necessary) and validates existence */
/* except for the staging directory path, which may be left blank */
%let _mscdm = %ms_clean_path(&_mscdm) ;
%let _qaresults = %ms_clean_path(&_qaresults) ;
%let _root_dplocal = %ms_clean_path(&_root_dplocal) ;
%let _root_msoc = %ms_clean_path(&_root_msoc) ;
%let _root_inputfiles = %ms_clean_path(&_root_inputfiles) ;
%let _root_sasprograms = %ms_clean_path(&_root_sasprograms) ;

/* If path is blank the macro %ms_lib will not assign libref*/
/* %ms_lib(libref-name, path-name, options=%str(options-name=options-value)) */
%ms_lib(indata, &_mscdm., options=%str(access=readonly)) 
%ms_lib(staging, &_staging., options=%str(access=readonly))
%ms_lib(qaresult, &_qaresults., options=%str(access=readonly)) 

/* Retrieve ETL metadata from production ETL */
%macro _get_ETL_metadata ;
   %put *********************************************************************************** ;
   %put Data partner ETL version number for the most recently approved MSCDM and QA results ;
   %put *********************************************************************************** ;

   %global ETL ;
   
   /* ETL 0 is the default value assigned when a DP onboards and does not yet have */
   /* an existing ETL approved for use in production queries */
   %let ETL = 0 ;  

   /* Retrieve the existing production ETL, if table exists */
   %if %sysfunc(exist(qaresult.etl_version)) ne 0 %then %do ;
      proc sql noprint ;
        select etl into :ETL 
          from qaresult.etl_version 
        ;
     quit ;
   %end ;
   %let ETL = &ETL ;  /* strip blanks for compatibility across SAS versions */  

   %put ;
   %put *** ETL: &ETL ;
   %put ;

   %put *********************************************************************************** ;
   %put Data partner dates of data completeness for the most recently approved ETL ;
   %put *********************************************************************************** ;


   %global DP_MinDate DP_MaxDate ;

   /* 01Jan2000 and 31Dec2099 are the default values assigned when a DP onboards */
   /* and does not yet have an existing ETL approved for use in production queries */
   %let DP_MinDate = '01Jan2000'd ;
   %let DP_MaxDate = '31Dec2099'd ;
   
   /* Retrieve the existing production Min/Max Dates, if table exists */
   %if %sysfunc(exist(qaresult.MinMax_Dates)) ne 0 %then %do ;   
      proc sql noprint ;
        select DP_MinDate format=best12., DP_MaxDate format=best12. 
                  into 
               :DP_MinDate, :DP_MaxDate
          from qaresult.MinMax_Dates
        ;
      quit ;  
   %end ;

   %put ;
   %put *** DP_MinDate: %sysfunc(putn(&DP_MinDate, date9.)) ;
   %put *** DP_MaxDate: %sysfunc(putn(&DP_MaxDate, date9.)) ;
   %put ;
   
%mend _get_ETL_metadata ;
%_get_ETL_metadata 

/* Delete macros that are no longer needed */
proc catalog catalog=work.sasmacr;
     delete _get_ETL_metadata / ET = macro;
quit;